import {Component, OnDestroy, OnInit} from '@angular/core';
import { Router, NavigationEnd, ActivatedRoute } from '@angular/router';
import { Title } from '@angular/platform-browser';
import {filter, map, mergeMap, takeUntil} from 'rxjs/operators';
import {Subject, Subscription} from 'rxjs';
import { AlertService } from './shared/alert/state/alert.service';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent implements OnInit, OnDestroy {
  constructor(
    private router: Router,
    private activatedRoute: ActivatedRoute,
    private titleService: Title,
    private alertService: AlertService
  ) {}

  private subscription: Subscription;
  private unsubscribe = new Subject<void>();

  ngOnInit() {
    this.subscription = this.router.events.pipe(
      filter(event => event instanceof NavigationEnd),
      map(() => {
        let route = this.activatedRoute;
        while (route.firstChild) {
          route = route.firstChild;
        }
        return route;
      }),
      mergeMap((route) => route.data),
    ).pipe(takeUntil(this.unsubscribe)).subscribe((event) => {
        this.titleService.setTitle(event['title']);
        this.alertService.clearEverything();
    });
  }

  ngOnDestroy(): void {
    this.unsubscribe.next();
    this.unsubscribe.complete();
  }
}


